# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RealmArgs', 'Realm']

@pulumi.input_type
class RealmArgs:
    def __init__(__self__, *,
                 realm_type: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Realm resource.
        :param pulumi.Input[_builtins.str] realm_type: The realm type. Valid values: `PARTNER` and `DEFAULT`
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm.
        """
        pulumi.set(__self__, "realm_type", realm_type)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="realmType")
    def realm_type(self) -> pulumi.Input[_builtins.str]:
        """
        The realm type. Valid values: `PARTNER` and `DEFAULT`
        """
        return pulumi.get(self, "realm_type")

    @realm_type.setter
    def realm_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "realm_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Okta Realm.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _RealmState:
    def __init__(__self__, *,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 realm_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Realm resources.
        :param pulumi.Input[_builtins.bool] is_default: Indicates whether the realm is the default realm.
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm.
        :param pulumi.Input[_builtins.str] realm_type: The realm type. Valid values: `PARTNER` and `DEFAULT`
        """
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if realm_type is not None:
            pulumi.set(__self__, "realm_type", realm_type)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the realm is the default realm.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Okta Realm.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="realmType")
    def realm_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The realm type. Valid values: `PARTNER` and `DEFAULT`
        """
        return pulumi.get(self, "realm_type")

    @realm_type.setter
    def realm_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "realm_type", value)


@pulumi.type_token("okta:index/realm:Realm")
class Realm(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 realm_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Okta Realm. This resource allows you to create and configure an Okta Realm.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Realm("example",
            name="Example Realm",
            realm_type="DEFAULT")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/realm:Realm example <realm_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm.
        :param pulumi.Input[_builtins.str] realm_type: The realm type. Valid values: `PARTNER` and `DEFAULT`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RealmArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Okta Realm. This resource allows you to create and configure an Okta Realm.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Realm("example",
            name="Example Realm",
            realm_type="DEFAULT")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/realm:Realm example <realm_id>
        ```

        :param str resource_name: The name of the resource.
        :param RealmArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RealmArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 realm_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RealmArgs.__new__(RealmArgs)

            __props__.__dict__["name"] = name
            if realm_type is None and not opts.urn:
                raise TypeError("Missing required property 'realm_type'")
            __props__.__dict__["realm_type"] = realm_type
            __props__.__dict__["is_default"] = None
        super(Realm, __self__).__init__(
            'okta:index/realm:Realm',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            realm_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Realm':
        """
        Get an existing Realm resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] is_default: Indicates whether the realm is the default realm.
        :param pulumi.Input[_builtins.str] name: The name of the Okta Realm.
        :param pulumi.Input[_builtins.str] realm_type: The realm type. Valid values: `PARTNER` and `DEFAULT`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RealmState.__new__(_RealmState)

        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["name"] = name
        __props__.__dict__["realm_type"] = realm_type
        return Realm(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the realm is the default realm.
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Okta Realm.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="realmType")
    def realm_type(self) -> pulumi.Output[_builtins.str]:
        """
        The realm type. Valid values: `PARTNER` and `DEFAULT`
        """
        return pulumi.get(self, "realm_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AppOauthApiScopeArgs', 'AppOauthApiScope']

@pulumi.input_type
class AppOauthApiScopeArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 issuer: pulumi.Input[_builtins.str],
                 scopes: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        """
        The set of arguments for constructing a AppOauthApiScope resource.
        :param pulumi.Input[_builtins.str] app_id: ID of the application.
        :param pulumi.Input[_builtins.str] issuer: The issuer of your Org Authorization Server, your Org URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the application for which consent is granted.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "issuer", issuer)
        pulumi.set(__self__, "scopes", scopes)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> pulumi.Input[_builtins.str]:
        """
        The issuer of your Org Authorization Server, your Org URL.
        """
        return pulumi.get(self, "issuer")

    @issuer.setter
    def issuer(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "issuer", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        Scopes of the application for which consent is granted.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "scopes", value)


@pulumi.input_type
class _AppOauthApiScopeState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AppOauthApiScope resources.
        :param pulumi.Input[_builtins.str] app_id: ID of the application.
        :param pulumi.Input[_builtins.str] issuer: The issuer of your Org Authorization Server, your Org URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the application for which consent is granted.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if issuer is not None:
            pulumi.set(__self__, "issuer", issuer)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The issuer of your Org Authorization Server, your Org URL.
        """
        return pulumi.get(self, "issuer")

    @issuer.setter
    def issuer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "issuer", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Scopes of the application for which consent is granted.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "scopes", value)


@pulumi.type_token("okta:index/appOauthApiScope:AppOauthApiScope")
class AppOauthApiScope(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages API scopes for OAuth applications.
        This resource allows you to grant or revoke API scopes for OAuth2 applications within your organization.
        Note: you have to create an application before using this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AppOauthApiScope("example",
            app_id="<application_id>",
            issuer="<your org domain>",
            scopes=[
                "okta.users.read",
                "okta.users.manage",
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appOauthApiScope:AppOauthApiScope example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: ID of the application.
        :param pulumi.Input[_builtins.str] issuer: The issuer of your Org Authorization Server, your Org URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the application for which consent is granted.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppOauthApiScopeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages API scopes for OAuth applications.
        This resource allows you to grant or revoke API scopes for OAuth2 applications within your organization.
        Note: you have to create an application before using this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AppOauthApiScope("example",
            app_id="<application_id>",
            issuer="<your org domain>",
            scopes=[
                "okta.users.read",
                "okta.users.manage",
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appOauthApiScope:AppOauthApiScope example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param AppOauthApiScopeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppOauthApiScopeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 issuer: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppOauthApiScopeArgs.__new__(AppOauthApiScopeArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if issuer is None and not opts.urn:
                raise TypeError("Missing required property 'issuer'")
            __props__.__dict__["issuer"] = issuer
            if scopes is None and not opts.urn:
                raise TypeError("Missing required property 'scopes'")
            __props__.__dict__["scopes"] = scopes
        super(AppOauthApiScope, __self__).__init__(
            'okta:index/appOauthApiScope:AppOauthApiScope',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            issuer: Optional[pulumi.Input[_builtins.str]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'AppOauthApiScope':
        """
        Get an existing AppOauthApiScope resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: ID of the application.
        :param pulumi.Input[_builtins.str] issuer: The issuer of your Org Authorization Server, your Org URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the application for which consent is granted.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppOauthApiScopeState.__new__(_AppOauthApiScopeState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["issuer"] = issuer
        __props__.__dict__["scopes"] = scopes
        return AppOauthApiScope(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> pulumi.Output[_builtins.str]:
        """
        The issuer of your Org Authorization Server, your Org URL.
        """
        return pulumi.get(self, "issuer")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Scopes of the application for which consent is granted.
        """
        return pulumi.get(self, "scopes")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ZoneArgs', 'Zone']

@pulumi.input_type
class ZoneArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Zone resource.
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        pulumi.set(__self__, "type", type)
        if asns is not None:
            pulumi.set(__self__, "asns", asns)
        if dynamic_locations is not None:
            pulumi.set(__self__, "dynamic_locations", dynamic_locations)
        if dynamic_locations_excludes is not None:
            pulumi.set(__self__, "dynamic_locations_excludes", dynamic_locations_excludes)
        if dynamic_proxy_type is not None:
            pulumi.set(__self__, "dynamic_proxy_type", dynamic_proxy_type)
        if gateways is not None:
            pulumi.set(__self__, "gateways", gateways)
        if ip_service_categories_excludes is not None:
            pulumi.set(__self__, "ip_service_categories_excludes", ip_service_categories_excludes)
        if ip_service_categories_includes is not None:
            pulumi.set(__self__, "ip_service_categories_includes", ip_service_categories_includes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if proxies is not None:
            pulumi.set(__self__, "proxies", proxies)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def asns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "asns")

    @asns.setter
    def asns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "asns", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocations")
    def dynamic_locations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations")

    @dynamic_locations.setter
    def dynamic_locations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocationsExcludes")
    def dynamic_locations_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations_excludes")

    @dynamic_locations_excludes.setter
    def dynamic_locations_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations_excludes", value)

    @_builtins.property
    @pulumi.getter(name="dynamicProxyType")
    def dynamic_proxy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        """
        return pulumi.get(self, "dynamic_proxy_type")

    @dynamic_proxy_type.setter
    def dynamic_proxy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dynamic_proxy_type", value)

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        """
        return pulumi.get(self, "gateways")

    @gateways.setter
    def gateways(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "gateways", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesExcludes")
    def ip_service_categories_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service excluded. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_excludes")

    @ip_service_categories_excludes.setter
    def ip_service_categories_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_excludes", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesIncludes")
    def ip_service_categories_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service included. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_includes")

    @ip_service_categories_includes.setter
    def ip_service_categories_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_includes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Network Zone Resource
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        """
        return pulumi.get(self, "proxies")

    @proxies.setter
    def proxies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "proxies", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Network Status - can either be `ACTIVE` or `INACTIVE` only
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage", value)


@pulumi.input_type
class _ZoneState:
    def __init__(__self__, *,
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Zone resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        if asns is not None:
            pulumi.set(__self__, "asns", asns)
        if dynamic_locations is not None:
            pulumi.set(__self__, "dynamic_locations", dynamic_locations)
        if dynamic_locations_excludes is not None:
            pulumi.set(__self__, "dynamic_locations_excludes", dynamic_locations_excludes)
        if dynamic_proxy_type is not None:
            pulumi.set(__self__, "dynamic_proxy_type", dynamic_proxy_type)
        if gateways is not None:
            pulumi.set(__self__, "gateways", gateways)
        if ip_service_categories_excludes is not None:
            pulumi.set(__self__, "ip_service_categories_excludes", ip_service_categories_excludes)
        if ip_service_categories_includes is not None:
            pulumi.set(__self__, "ip_service_categories_includes", ip_service_categories_includes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if proxies is not None:
            pulumi.set(__self__, "proxies", proxies)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)

    @_builtins.property
    @pulumi.getter
    def asns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "asns")

    @asns.setter
    def asns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "asns", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocations")
    def dynamic_locations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations")

    @dynamic_locations.setter
    def dynamic_locations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations", value)

    @_builtins.property
    @pulumi.getter(name="dynamicLocationsExcludes")
    def dynamic_locations_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations_excludes")

    @dynamic_locations_excludes.setter
    def dynamic_locations_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dynamic_locations_excludes", value)

    @_builtins.property
    @pulumi.getter(name="dynamicProxyType")
    def dynamic_proxy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        """
        return pulumi.get(self, "dynamic_proxy_type")

    @dynamic_proxy_type.setter
    def dynamic_proxy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dynamic_proxy_type", value)

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        """
        return pulumi.get(self, "gateways")

    @gateways.setter
    def gateways(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "gateways", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesExcludes")
    def ip_service_categories_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service excluded. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_excludes")

    @ip_service_categories_excludes.setter
    def ip_service_categories_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_excludes", value)

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesIncludes")
    def ip_service_categories_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of ip service included. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_includes")

    @ip_service_categories_includes.setter
    def ip_service_categories_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_service_categories_includes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Network Zone Resource
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        """
        return pulumi.get(self, "proxies")

    @proxies.setter
    def proxies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "proxies", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Network Status - can either be `ACTIVE` or `INACTIVE` only
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage", value)


@pulumi.type_token("okta:network/zone:Zone")
class Zone(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Okta Network Zone. This resource allows you to create and configure an Okta Network Zone.

        ## Import

        ```sh
        $ pulumi import okta:network/zone:Zone example <zone_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ZoneArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Okta Network Zone. This resource allows you to create and configure an Okta Network Zone.

        ## Import

        ```sh
        $ pulumi import okta:network/zone:Zone example <zone_id>
        ```

        :param str resource_name: The name of the resource.
        :param ZoneArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ZoneArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ZoneArgs.__new__(ZoneArgs)

            __props__.__dict__["asns"] = asns
            __props__.__dict__["dynamic_locations"] = dynamic_locations
            __props__.__dict__["dynamic_locations_excludes"] = dynamic_locations_excludes
            __props__.__dict__["dynamic_proxy_type"] = dynamic_proxy_type
            __props__.__dict__["gateways"] = gateways
            __props__.__dict__["ip_service_categories_excludes"] = ip_service_categories_excludes
            __props__.__dict__["ip_service_categories_includes"] = ip_service_categories_includes
            __props__.__dict__["name"] = name
            __props__.__dict__["proxies"] = proxies
            __props__.__dict__["status"] = status
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["usage"] = usage
        super(Zone, __self__).__init__(
            'okta:network/zone:Zone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dynamic_locations: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dynamic_locations_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dynamic_proxy_type: Optional[pulumi.Input[_builtins.str]] = None,
            gateways: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ip_service_categories_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ip_service_categories_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            proxies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            usage: Optional[pulumi.Input[_builtins.str]] = None) -> 'Zone':
        """
        Get an existing Zone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] asns: List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations: Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dynamic_locations_excludes: Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] dynamic_proxy_type: Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] gateways: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_excludes: List of ip service excluded. Use with type `DYNAMIC_V2`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_service_categories_includes: List of ip service included. Use with type `DYNAMIC_V2`
        :param pulumi.Input[_builtins.str] name: Name of the Network Zone Resource
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] proxies: Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        :param pulumi.Input[_builtins.str] status: Network Status - can either be `ACTIVE` or `INACTIVE` only
        :param pulumi.Input[_builtins.str] type: Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        :param pulumi.Input[_builtins.str] usage: Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ZoneState.__new__(_ZoneState)

        __props__.__dict__["asns"] = asns
        __props__.__dict__["dynamic_locations"] = dynamic_locations
        __props__.__dict__["dynamic_locations_excludes"] = dynamic_locations_excludes
        __props__.__dict__["dynamic_proxy_type"] = dynamic_proxy_type
        __props__.__dict__["gateways"] = gateways
        __props__.__dict__["ip_service_categories_excludes"] = ip_service_categories_excludes
        __props__.__dict__["ip_service_categories_includes"] = ip_service_categories_includes
        __props__.__dict__["name"] = name
        __props__.__dict__["proxies"] = proxies
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        __props__.__dict__["usage"] = usage
        return Zone(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def asns(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of asns included. Format of each array value: a string representation of an ASN numeric value. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "asns")

    @_builtins.property
    @pulumi.getter(name="dynamicLocations")
    def dynamic_locations(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of locations ISO-3166-1(2) included. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC` or `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations")

    @_builtins.property
    @pulumi.getter(name="dynamicLocationsExcludes")
    def dynamic_locations_excludes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of locations ISO-3166-1(2) excluded. Format code: countryCode OR countryCode-regionCode. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "dynamic_locations_excludes")

    @_builtins.property
    @pulumi.getter(name="dynamicProxyType")
    def dynamic_proxy_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Type of proxy being controlled by this dynamic network zone - can be one of `Any`, `TorAnonymizer` or `NotTorAnonymizer`. Use with type `DYNAMIC`
        """
        return pulumi.get(self, "dynamic_proxy_type")

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Use with type `IP`
        """
        return pulumi.get(self, "gateways")

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesExcludes")
    def ip_service_categories_excludes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of ip service excluded. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_excludes")

    @_builtins.property
    @pulumi.getter(name="ipServiceCategoriesIncludes")
    def ip_service_categories_includes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of ip service included. Use with type `DYNAMIC_V2`
        """
        return pulumi.get(self, "ip_service_categories_includes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Network Zone Resource
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def proxies(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of values in CIDR/range form depending on the way it's been declared (i.e. CIDR will contain /suffix). Please check API docs for examples. Can not be set if `usage` is set to `BLOCKLIST`. Use with type `IP`
        """
        return pulumi.get(self, "proxies")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Network Status - can either be `ACTIVE` or `INACTIVE` only
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the Network Zone - can be `IP`, `DYNAMIC` or `DYNAMIC_V2` only
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def usage(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Usage of the Network Zone - can be either `POLICY` or `BLOCKLIST`. By default, it is `POLICY`
        """
        return pulumi.get(self, "usage")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PolicyRuleProfileEnrollmentArgs', 'PolicyRuleProfileEnrollment']

@pulumi.input_type
class PolicyRuleProfileEnrollmentArgs:
    def __init__(__self__, *,
                 policy_id: pulumi.Input[_builtins.str],
                 unknown_user_action: pulumi.Input[_builtins.str],
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 email_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 enroll_authenticator_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 inline_hook_id: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]]] = None,
                 progressive_profiling_action: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ui_schema_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PolicyRuleProfileEnrollment resource.
        :param pulumi.Input[_builtins.str] policy_id: ID of the policy
        :param pulumi.Input[_builtins.str] unknown_user_action: Which action should be taken if this User is new. Valid values are: `DENY`, `REGISTER`
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions. Valid values are: `ALLOW`, `DENY`. Default: `ALLOW`.
        :param pulumi.Input[_builtins.bool] email_verification: Indicates whether email verification should occur before access is granted. Default: `true`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enroll_authenticator_types: Enrolls authenticator types
        :param pulumi.Input[_builtins.str] inline_hook_id: ID of a Registration Inline Hook
        :param pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]] profile_attributes: A list of attributes to prompt the user during registration or progressive profiling. Where defined on the User schema, these attributes are persisted in the User profile. Non-schema attributes may also be added, which aren't persisted to the User's profile, but are included in requests to the registration inline hook. A maximum of 10 Profile properties is supported.
               	- 'label' - (Required) A display-friendly label for this property
               	- 'name' - (Required) The name of a User Profile property
               	- 'required' - (Required) Indicates if this property is required for enrollment. Default is 'false'.
        :param pulumi.Input[_builtins.str] progressive_profiling_action: Enabled or disabled progressive profiling action rule conditions: `ENABLED` or `DISABLED`. Default: `DISABLED`
        :param pulumi.Input[_builtins.str] target_group_id: The ID of a Group that this User should be added to
        :param pulumi.Input[_builtins.str] ui_schema_id: Value created by the backend. If present all policy updates must include this attribute/value.
        """
        pulumi.set(__self__, "policy_id", policy_id)
        pulumi.set(__self__, "unknown_user_action", unknown_user_action)
        if access is not None:
            pulumi.set(__self__, "access", access)
        if email_verification is not None:
            pulumi.set(__self__, "email_verification", email_verification)
        if enroll_authenticator_types is not None:
            pulumi.set(__self__, "enroll_authenticator_types", enroll_authenticator_types)
        if inline_hook_id is not None:
            pulumi.set(__self__, "inline_hook_id", inline_hook_id)
        if profile_attributes is not None:
            pulumi.set(__self__, "profile_attributes", profile_attributes)
        if progressive_profiling_action is not None:
            pulumi.set(__self__, "progressive_profiling_action", progressive_profiling_action)
        if target_group_id is not None:
            pulumi.set(__self__, "target_group_id", target_group_id)
        if ui_schema_id is not None:
            pulumi.set(__self__, "ui_schema_id", ui_schema_id)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the policy
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="unknownUserAction")
    def unknown_user_action(self) -> pulumi.Input[_builtins.str]:
        """
        Which action should be taken if this User is new. Valid values are: `DENY`, `REGISTER`
        """
        return pulumi.get(self, "unknown_user_action")

    @unknown_user_action.setter
    def unknown_user_action(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "unknown_user_action", value)

    @_builtins.property
    @pulumi.getter
    def access(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allow or deny access based on the rule conditions. Valid values are: `ALLOW`, `DENY`. Default: `ALLOW`.
        """
        return pulumi.get(self, "access")

    @access.setter
    def access(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access", value)

    @_builtins.property
    @pulumi.getter(name="emailVerification")
    def email_verification(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether email verification should occur before access is granted. Default: `true`.
        """
        return pulumi.get(self, "email_verification")

    @email_verification.setter
    def email_verification(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "email_verification", value)

    @_builtins.property
    @pulumi.getter(name="enrollAuthenticatorTypes")
    def enroll_authenticator_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Enrolls authenticator types
        """
        return pulumi.get(self, "enroll_authenticator_types")

    @enroll_authenticator_types.setter
    def enroll_authenticator_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enroll_authenticator_types", value)

    @_builtins.property
    @pulumi.getter(name="inlineHookId")
    def inline_hook_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of a Registration Inline Hook
        """
        return pulumi.get(self, "inline_hook_id")

    @inline_hook_id.setter
    def inline_hook_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "inline_hook_id", value)

    @_builtins.property
    @pulumi.getter(name="profileAttributes")
    def profile_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]]]:
        """
        A list of attributes to prompt the user during registration or progressive profiling. Where defined on the User schema, these attributes are persisted in the User profile. Non-schema attributes may also be added, which aren't persisted to the User's profile, but are included in requests to the registration inline hook. A maximum of 10 Profile properties is supported.
        	- 'label' - (Required) A display-friendly label for this property
        	- 'name' - (Required) The name of a User Profile property
        	- 'required' - (Required) Indicates if this property is required for enrollment. Default is 'false'.
        """
        return pulumi.get(self, "profile_attributes")

    @profile_attributes.setter
    def profile_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]]]):
        pulumi.set(self, "profile_attributes", value)

    @_builtins.property
    @pulumi.getter(name="progressiveProfilingAction")
    def progressive_profiling_action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enabled or disabled progressive profiling action rule conditions: `ENABLED` or `DISABLED`. Default: `DISABLED`
        """
        return pulumi.get(self, "progressive_profiling_action")

    @progressive_profiling_action.setter
    def progressive_profiling_action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "progressive_profiling_action", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of a Group that this User should be added to
        """
        return pulumi.get(self, "target_group_id")

    @target_group_id.setter
    def target_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_group_id", value)

    @_builtins.property
    @pulumi.getter(name="uiSchemaId")
    def ui_schema_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value created by the backend. If present all policy updates must include this attribute/value.
        """
        return pulumi.get(self, "ui_schema_id")

    @ui_schema_id.setter
    def ui_schema_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ui_schema_id", value)


@pulumi.input_type
class _PolicyRuleProfileEnrollmentState:
    def __init__(__self__, *,
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 email_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 enroll_authenticator_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 inline_hook_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]]] = None,
                 progressive_profiling_action: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ui_schema_id: Optional[pulumi.Input[_builtins.str]] = None,
                 unknown_user_action: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PolicyRuleProfileEnrollment resources.
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions. Valid values are: `ALLOW`, `DENY`. Default: `ALLOW`.
        :param pulumi.Input[_builtins.bool] email_verification: Indicates whether email verification should occur before access is granted. Default: `true`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enroll_authenticator_types: Enrolls authenticator types
        :param pulumi.Input[_builtins.str] inline_hook_id: ID of a Registration Inline Hook
        :param pulumi.Input[_builtins.str] name: Name of the rule
        :param pulumi.Input[_builtins.str] policy_id: ID of the policy
        :param pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]] profile_attributes: A list of attributes to prompt the user during registration or progressive profiling. Where defined on the User schema, these attributes are persisted in the User profile. Non-schema attributes may also be added, which aren't persisted to the User's profile, but are included in requests to the registration inline hook. A maximum of 10 Profile properties is supported.
               	- 'label' - (Required) A display-friendly label for this property
               	- 'name' - (Required) The name of a User Profile property
               	- 'required' - (Required) Indicates if this property is required for enrollment. Default is 'false'.
        :param pulumi.Input[_builtins.str] progressive_profiling_action: Enabled or disabled progressive profiling action rule conditions: `ENABLED` or `DISABLED`. Default: `DISABLED`
        :param pulumi.Input[_builtins.str] status: Status of the rule
        :param pulumi.Input[_builtins.str] target_group_id: The ID of a Group that this User should be added to
        :param pulumi.Input[_builtins.str] ui_schema_id: Value created by the backend. If present all policy updates must include this attribute/value.
        :param pulumi.Input[_builtins.str] unknown_user_action: Which action should be taken if this User is new. Valid values are: `DENY`, `REGISTER`
        """
        if access is not None:
            pulumi.set(__self__, "access", access)
        if email_verification is not None:
            pulumi.set(__self__, "email_verification", email_verification)
        if enroll_authenticator_types is not None:
            pulumi.set(__self__, "enroll_authenticator_types", enroll_authenticator_types)
        if inline_hook_id is not None:
            pulumi.set(__self__, "inline_hook_id", inline_hook_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if profile_attributes is not None:
            pulumi.set(__self__, "profile_attributes", profile_attributes)
        if progressive_profiling_action is not None:
            pulumi.set(__self__, "progressive_profiling_action", progressive_profiling_action)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target_group_id is not None:
            pulumi.set(__self__, "target_group_id", target_group_id)
        if ui_schema_id is not None:
            pulumi.set(__self__, "ui_schema_id", ui_schema_id)
        if unknown_user_action is not None:
            pulumi.set(__self__, "unknown_user_action", unknown_user_action)

    @_builtins.property
    @pulumi.getter
    def access(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allow or deny access based on the rule conditions. Valid values are: `ALLOW`, `DENY`. Default: `ALLOW`.
        """
        return pulumi.get(self, "access")

    @access.setter
    def access(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access", value)

    @_builtins.property
    @pulumi.getter(name="emailVerification")
    def email_verification(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether email verification should occur before access is granted. Default: `true`.
        """
        return pulumi.get(self, "email_verification")

    @email_verification.setter
    def email_verification(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "email_verification", value)

    @_builtins.property
    @pulumi.getter(name="enrollAuthenticatorTypes")
    def enroll_authenticator_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Enrolls authenticator types
        """
        return pulumi.get(self, "enroll_authenticator_types")

    @enroll_authenticator_types.setter
    def enroll_authenticator_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enroll_authenticator_types", value)

    @_builtins.property
    @pulumi.getter(name="inlineHookId")
    def inline_hook_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of a Registration Inline Hook
        """
        return pulumi.get(self, "inline_hook_id")

    @inline_hook_id.setter
    def inline_hook_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "inline_hook_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the policy
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="profileAttributes")
    def profile_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]]]:
        """
        A list of attributes to prompt the user during registration or progressive profiling. Where defined on the User schema, these attributes are persisted in the User profile. Non-schema attributes may also be added, which aren't persisted to the User's profile, but are included in requests to the registration inline hook. A maximum of 10 Profile properties is supported.
        	- 'label' - (Required) A display-friendly label for this property
        	- 'name' - (Required) The name of a User Profile property
        	- 'required' - (Required) Indicates if this property is required for enrollment. Default is 'false'.
        """
        return pulumi.get(self, "profile_attributes")

    @profile_attributes.setter
    def profile_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyRuleProfileEnrollmentProfileAttributeArgs']]]]):
        pulumi.set(self, "profile_attributes", value)

    @_builtins.property
    @pulumi.getter(name="progressiveProfilingAction")
    def progressive_profiling_action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enabled or disabled progressive profiling action rule conditions: `ENABLED` or `DISABLED`. Default: `DISABLED`
        """
        return pulumi.get(self, "progressive_profiling_action")

    @progressive_profiling_action.setter
    def progressive_profiling_action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "progressive_profiling_action", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the rule
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of a Group that this User should be added to
        """
        return pulumi.get(self, "target_group_id")

    @target_group_id.setter
    def target_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_group_id", value)

    @_builtins.property
    @pulumi.getter(name="uiSchemaId")
    def ui_schema_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value created by the backend. If present all policy updates must include this attribute/value.
        """
        return pulumi.get(self, "ui_schema_id")

    @ui_schema_id.setter
    def ui_schema_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ui_schema_id", value)

    @_builtins.property
    @pulumi.getter(name="unknownUserAction")
    def unknown_user_action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Which action should be taken if this User is new. Valid values are: `DENY`, `REGISTER`
        """
        return pulumi.get(self, "unknown_user_action")

    @unknown_user_action.setter
    def unknown_user_action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "unknown_user_action", value)


@pulumi.type_token("okta:index/policyRuleProfileEnrollment:PolicyRuleProfileEnrollment")
class PolicyRuleProfileEnrollment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 email_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 enroll_authenticator_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 inline_hook_id: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleProfileEnrollmentProfileAttributeArgs', 'PolicyRuleProfileEnrollmentProfileAttributeArgsDict']]]]] = None,
                 progressive_profiling_action: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ui_schema_id: Optional[pulumi.Input[_builtins.str]] = None,
                 unknown_user_action: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates a Profile Enrollment Policy Rule.

        > **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.
        A [profile enrollment
        policy](https://developer.okta.com/docs/reference/api/policy/#profile-enrollment-policy)
        is limited to one default rule. This resource does not create a rule for an
        enrollment policy, it allows the default policy rule to be updated.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.PolicyProfileEnrollment("example", name="My Enrollment Policy")
        example_hook = okta.inline.Hook("example",
            name="My Inline Hook",
            status="ACTIVE",
            type="com.okta.user.pre-registration",
            version="1.0.3",
            channel={
                "type": "HTTP",
                "version": "1.0.0",
                "uri": "https://example.com/test2",
                "method": "POST",
            })
        example_group = okta.group.Group("example",
            name="My Group",
            description="Group of some users")
        example_policy_rule_profile_enrollment = okta.PolicyRuleProfileEnrollment("example",
            policy_id=example.id,
            inline_hook_id=example_hook.id,
            target_group_id=example_group.id,
            unknown_user_action="REGISTER",
            email_verification=True,
            access="ALLOW",
            profile_attributes=[
                {
                    "name": "email",
                    "label": "Email",
                    "required": True,
                },
                {
                    "name": "name",
                    "label": "Name",
                    "required": True,
                },
                {
                    "name": "t-shirt",
                    "label": "T-Shirt Size",
                    "required": False,
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/policyRuleProfileEnrollment:PolicyRuleProfileEnrollment example <policy_id>/<rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions. Valid values are: `ALLOW`, `DENY`. Default: `ALLOW`.
        :param pulumi.Input[_builtins.bool] email_verification: Indicates whether email verification should occur before access is granted. Default: `true`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enroll_authenticator_types: Enrolls authenticator types
        :param pulumi.Input[_builtins.str] inline_hook_id: ID of a Registration Inline Hook
        :param pulumi.Input[_builtins.str] policy_id: ID of the policy
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleProfileEnrollmentProfileAttributeArgs', 'PolicyRuleProfileEnrollmentProfileAttributeArgsDict']]]] profile_attributes: A list of attributes to prompt the user during registration or progressive profiling. Where defined on the User schema, these attributes are persisted in the User profile. Non-schema attributes may also be added, which aren't persisted to the User's profile, but are included in requests to the registration inline hook. A maximum of 10 Profile properties is supported.
               	- 'label' - (Required) A display-friendly label for this property
               	- 'name' - (Required) The name of a User Profile property
               	- 'required' - (Required) Indicates if this property is required for enrollment. Default is 'false'.
        :param pulumi.Input[_builtins.str] progressive_profiling_action: Enabled or disabled progressive profiling action rule conditions: `ENABLED` or `DISABLED`. Default: `DISABLED`
        :param pulumi.Input[_builtins.str] target_group_id: The ID of a Group that this User should be added to
        :param pulumi.Input[_builtins.str] ui_schema_id: Value created by the backend. If present all policy updates must include this attribute/value.
        :param pulumi.Input[_builtins.str] unknown_user_action: Which action should be taken if this User is new. Valid values are: `DENY`, `REGISTER`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicyRuleProfileEnrollmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Profile Enrollment Policy Rule.

        > **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.
        A [profile enrollment
        policy](https://developer.okta.com/docs/reference/api/policy/#profile-enrollment-policy)
        is limited to one default rule. This resource does not create a rule for an
        enrollment policy, it allows the default policy rule to be updated.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.PolicyProfileEnrollment("example", name="My Enrollment Policy")
        example_hook = okta.inline.Hook("example",
            name="My Inline Hook",
            status="ACTIVE",
            type="com.okta.user.pre-registration",
            version="1.0.3",
            channel={
                "type": "HTTP",
                "version": "1.0.0",
                "uri": "https://example.com/test2",
                "method": "POST",
            })
        example_group = okta.group.Group("example",
            name="My Group",
            description="Group of some users")
        example_policy_rule_profile_enrollment = okta.PolicyRuleProfileEnrollment("example",
            policy_id=example.id,
            inline_hook_id=example_hook.id,
            target_group_id=example_group.id,
            unknown_user_action="REGISTER",
            email_verification=True,
            access="ALLOW",
            profile_attributes=[
                {
                    "name": "email",
                    "label": "Email",
                    "required": True,
                },
                {
                    "name": "name",
                    "label": "Name",
                    "required": True,
                },
                {
                    "name": "t-shirt",
                    "label": "T-Shirt Size",
                    "required": False,
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/policyRuleProfileEnrollment:PolicyRuleProfileEnrollment example <policy_id>/<rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param PolicyRuleProfileEnrollmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyRuleProfileEnrollmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 email_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 enroll_authenticator_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 inline_hook_id: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 profile_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleProfileEnrollmentProfileAttributeArgs', 'PolicyRuleProfileEnrollmentProfileAttributeArgsDict']]]]] = None,
                 progressive_profiling_action: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ui_schema_id: Optional[pulumi.Input[_builtins.str]] = None,
                 unknown_user_action: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyRuleProfileEnrollmentArgs.__new__(PolicyRuleProfileEnrollmentArgs)

            __props__.__dict__["access"] = access
            __props__.__dict__["email_verification"] = email_verification
            __props__.__dict__["enroll_authenticator_types"] = enroll_authenticator_types
            __props__.__dict__["inline_hook_id"] = inline_hook_id
            if policy_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_id'")
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["profile_attributes"] = profile_attributes
            __props__.__dict__["progressive_profiling_action"] = progressive_profiling_action
            __props__.__dict__["target_group_id"] = target_group_id
            __props__.__dict__["ui_schema_id"] = ui_schema_id
            if unknown_user_action is None and not opts.urn:
                raise TypeError("Missing required property 'unknown_user_action'")
            __props__.__dict__["unknown_user_action"] = unknown_user_action
            __props__.__dict__["name"] = None
            __props__.__dict__["status"] = None
        super(PolicyRuleProfileEnrollment, __self__).__init__(
            'okta:index/policyRuleProfileEnrollment:PolicyRuleProfileEnrollment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access: Optional[pulumi.Input[_builtins.str]] = None,
            email_verification: Optional[pulumi.Input[_builtins.bool]] = None,
            enroll_authenticator_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            inline_hook_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            profile_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleProfileEnrollmentProfileAttributeArgs', 'PolicyRuleProfileEnrollmentProfileAttributeArgsDict']]]]] = None,
            progressive_profiling_action: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            ui_schema_id: Optional[pulumi.Input[_builtins.str]] = None,
            unknown_user_action: Optional[pulumi.Input[_builtins.str]] = None) -> 'PolicyRuleProfileEnrollment':
        """
        Get an existing PolicyRuleProfileEnrollment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions. Valid values are: `ALLOW`, `DENY`. Default: `ALLOW`.
        :param pulumi.Input[_builtins.bool] email_verification: Indicates whether email verification should occur before access is granted. Default: `true`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enroll_authenticator_types: Enrolls authenticator types
        :param pulumi.Input[_builtins.str] inline_hook_id: ID of a Registration Inline Hook
        :param pulumi.Input[_builtins.str] name: Name of the rule
        :param pulumi.Input[_builtins.str] policy_id: ID of the policy
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicyRuleProfileEnrollmentProfileAttributeArgs', 'PolicyRuleProfileEnrollmentProfileAttributeArgsDict']]]] profile_attributes: A list of attributes to prompt the user during registration or progressive profiling. Where defined on the User schema, these attributes are persisted in the User profile. Non-schema attributes may also be added, which aren't persisted to the User's profile, but are included in requests to the registration inline hook. A maximum of 10 Profile properties is supported.
               	- 'label' - (Required) A display-friendly label for this property
               	- 'name' - (Required) The name of a User Profile property
               	- 'required' - (Required) Indicates if this property is required for enrollment. Default is 'false'.
        :param pulumi.Input[_builtins.str] progressive_profiling_action: Enabled or disabled progressive profiling action rule conditions: `ENABLED` or `DISABLED`. Default: `DISABLED`
        :param pulumi.Input[_builtins.str] status: Status of the rule
        :param pulumi.Input[_builtins.str] target_group_id: The ID of a Group that this User should be added to
        :param pulumi.Input[_builtins.str] ui_schema_id: Value created by the backend. If present all policy updates must include this attribute/value.
        :param pulumi.Input[_builtins.str] unknown_user_action: Which action should be taken if this User is new. Valid values are: `DENY`, `REGISTER`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyRuleProfileEnrollmentState.__new__(_PolicyRuleProfileEnrollmentState)

        __props__.__dict__["access"] = access
        __props__.__dict__["email_verification"] = email_verification
        __props__.__dict__["enroll_authenticator_types"] = enroll_authenticator_types
        __props__.__dict__["inline_hook_id"] = inline_hook_id
        __props__.__dict__["name"] = name
        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["profile_attributes"] = profile_attributes
        __props__.__dict__["progressive_profiling_action"] = progressive_profiling_action
        __props__.__dict__["status"] = status
        __props__.__dict__["target_group_id"] = target_group_id
        __props__.__dict__["ui_schema_id"] = ui_schema_id
        __props__.__dict__["unknown_user_action"] = unknown_user_action
        return PolicyRuleProfileEnrollment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def access(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Allow or deny access based on the rule conditions. Valid values are: `ALLOW`, `DENY`. Default: `ALLOW`.
        """
        return pulumi.get(self, "access")

    @_builtins.property
    @pulumi.getter(name="emailVerification")
    def email_verification(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whether email verification should occur before access is granted. Default: `true`.
        """
        return pulumi.get(self, "email_verification")

    @_builtins.property
    @pulumi.getter(name="enrollAuthenticatorTypes")
    def enroll_authenticator_types(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Enrolls authenticator types
        """
        return pulumi.get(self, "enroll_authenticator_types")

    @_builtins.property
    @pulumi.getter(name="inlineHookId")
    def inline_hook_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of a Registration Inline Hook
        """
        return pulumi.get(self, "inline_hook_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the policy
        """
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter(name="profileAttributes")
    def profile_attributes(self) -> pulumi.Output[Optional[Sequence['outputs.PolicyRuleProfileEnrollmentProfileAttribute']]]:
        """
        A list of attributes to prompt the user during registration or progressive profiling. Where defined on the User schema, these attributes are persisted in the User profile. Non-schema attributes may also be added, which aren't persisted to the User's profile, but are included in requests to the registration inline hook. A maximum of 10 Profile properties is supported.
        	- 'label' - (Required) A display-friendly label for this property
        	- 'name' - (Required) The name of a User Profile property
        	- 'required' - (Required) Indicates if this property is required for enrollment. Default is 'false'.
        """
        return pulumi.get(self, "profile_attributes")

    @_builtins.property
    @pulumi.getter(name="progressiveProfilingAction")
    def progressive_profiling_action(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Enabled or disabled progressive profiling action rule conditions: `ENABLED` or `DISABLED`. Default: `DISABLED`
        """
        return pulumi.get(self, "progressive_profiling_action")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the rule
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of a Group that this User should be added to
        """
        return pulumi.get(self, "target_group_id")

    @_builtins.property
    @pulumi.getter(name="uiSchemaId")
    def ui_schema_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Value created by the backend. If present all policy updates must include this attribute/value.
        """
        return pulumi.get(self, "ui_schema_id")

    @_builtins.property
    @pulumi.getter(name="unknownUserAction")
    def unknown_user_action(self) -> pulumi.Output[_builtins.str]:
        """
        Which action should be taken if this User is new. Valid values are: `DENY`, `REGISTER`
        """
        return pulumi.get(self, "unknown_user_action")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserAdminRolesArgs', 'UserAdminRoles']

@pulumi.input_type
class UserAdminRolesArgs:
    def __init__(__self__, *,
                 admin_roles: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 user_id: pulumi.Input[_builtins.str],
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a UserAdminRoles resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admin_roles: The list of Okta user admin roles, e.g. `['APP_ADMIN', 'USER_ADMIN']` See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        """
        pulumi.set(__self__, "admin_roles", admin_roles)
        pulumi.set(__self__, "user_id", user_id)
        if disable_notifications is not None:
            pulumi.set(__self__, "disable_notifications", disable_notifications)

    @_builtins.property
    @pulumi.getter(name="adminRoles")
    def admin_roles(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The list of Okta user admin roles, e.g. `['APP_ADMIN', 'USER_ADMIN']` See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        """
        return pulumi.get(self, "admin_roles")

    @admin_roles.setter
    def admin_roles(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "admin_roles", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of a Okta User
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "user_id", value)

    @_builtins.property
    @pulumi.getter(name="disableNotifications")
    def disable_notifications(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        """
        return pulumi.get(self, "disable_notifications")

    @disable_notifications.setter
    def disable_notifications(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_notifications", value)


@pulumi.input_type
class _UserAdminRolesState:
    def __init__(__self__, *,
                 admin_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering UserAdminRoles resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admin_roles: The list of Okta user admin roles, e.g. `['APP_ADMIN', 'USER_ADMIN']` See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        """
        if admin_roles is not None:
            pulumi.set(__self__, "admin_roles", admin_roles)
        if disable_notifications is not None:
            pulumi.set(__self__, "disable_notifications", disable_notifications)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="adminRoles")
    def admin_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of Okta user admin roles, e.g. `['APP_ADMIN', 'USER_ADMIN']` See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        """
        return pulumi.get(self, "admin_roles")

    @admin_roles.setter
    def admin_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "admin_roles", value)

    @_builtins.property
    @pulumi.getter(name="disableNotifications")
    def disable_notifications(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        """
        return pulumi.get(self, "disable_notifications")

    @disable_notifications.setter
    def disable_notifications(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_notifications", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of a Okta User
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("okta:index/userAdminRoles:UserAdminRoles")
class UserAdminRoles(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource to manage a set of administrator roles for a specific user. This resource allows you to manage admin roles for a single user, independent of the user schema itself.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.user.User("test",
            first_name="TestAcc",
            last_name="Smith",
            login="testAcc-replace_with_uuid@example.com",
            email="testAcc-replace_with_uuid@example.com")
        test_user_admin_roles = okta.UserAdminRoles("test",
            user_id=test.id,
            admin_roles=["APP_ADMIN"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/userAdminRoles:UserAdminRoles example <user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admin_roles: The list of Okta user admin roles, e.g. `['APP_ADMIN', 'USER_ADMIN']` See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserAdminRolesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource to manage a set of administrator roles for a specific user. This resource allows you to manage admin roles for a single user, independent of the user schema itself.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.user.User("test",
            first_name="TestAcc",
            last_name="Smith",
            login="testAcc-replace_with_uuid@example.com",
            email="testAcc-replace_with_uuid@example.com")
        test_user_admin_roles = okta.UserAdminRoles("test",
            user_id=test.id,
            admin_roles=["APP_ADMIN"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/userAdminRoles:UserAdminRoles example <user_id>
        ```

        :param str resource_name: The name of the resource.
        :param UserAdminRolesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserAdminRolesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserAdminRolesArgs.__new__(UserAdminRolesArgs)

            if admin_roles is None and not opts.urn:
                raise TypeError("Missing required property 'admin_roles'")
            __props__.__dict__["admin_roles"] = admin_roles
            __props__.__dict__["disable_notifications"] = disable_notifications
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(UserAdminRoles, __self__).__init__(
            'okta:index/userAdminRoles:UserAdminRoles',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            admin_roles: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            disable_notifications: Optional[pulumi.Input[_builtins.bool]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'UserAdminRoles':
        """
        Get an existing UserAdminRoles resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] admin_roles: The list of Okta user admin roles, e.g. `['APP_ADMIN', 'USER_ADMIN']` See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        :param pulumi.Input[_builtins.bool] disable_notifications: When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserAdminRolesState.__new__(_UserAdminRolesState)

        __props__.__dict__["admin_roles"] = admin_roles
        __props__.__dict__["disable_notifications"] = disable_notifications
        __props__.__dict__["user_id"] = user_id
        return UserAdminRoles(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="adminRoles")
    def admin_roles(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The list of Okta user admin roles, e.g. `['APP_ADMIN', 'USER_ADMIN']` See [API Docs](https://developer.okta.com/docs/api/openapi/okta-management/guides/roles/#standard-roles).
        """
        return pulumi.get(self, "admin_roles")

    @_builtins.property
    @pulumi.getter(name="disableNotifications")
    def disable_notifications(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When this setting is enabled, the admins won't receive any of the default Okta administrator emails. These admins also won't have access to contact Okta Support and open support cases on behalf of your org.
        """
        return pulumi.get(self, "disable_notifications")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of a Okta User
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DomainArgs', 'Domain']

@pulumi.input_type
class DomainArgs:
    def __init__(__self__, *,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Domain resource.
        :param pulumi.Input[_builtins.str] brand_id: Brand id of the domain
        :param pulumi.Input[_builtins.str] certificate_source_type: Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: `MANUAL`, `OKTA_MANAGED`. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
        :param pulumi.Input[_builtins.str] name: Custom Domain name
        """
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if certificate_source_type is not None:
            pulumi.set(__self__, "certificate_source_type", certificate_source_type)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Brand id of the domain
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="certificateSourceType")
    def certificate_source_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: `MANUAL`, `OKTA_MANAGED`. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
        """
        return pulumi.get(self, "certificate_source_type")

    @certificate_source_type.setter
    def certificate_source_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_source_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom Domain name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DomainState:
    def __init__(__self__, *,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_records: Optional[pulumi.Input[Sequence[pulumi.Input['DomainDnsRecordArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 validation_status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Domain resources.
        :param pulumi.Input[_builtins.str] brand_id: Brand id of the domain
        :param pulumi.Input[_builtins.str] certificate_source_type: Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: `MANUAL`, `OKTA_MANAGED`. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
        :param pulumi.Input[Sequence[pulumi.Input['DomainDnsRecordArgs']]] dns_records: TXT and CNAME records to be registered for the Domain
        :param pulumi.Input[_builtins.str] name: Custom Domain name
        :param pulumi.Input[_builtins.str] validation_status: Status of the domain
        """
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if certificate_source_type is not None:
            pulumi.set(__self__, "certificate_source_type", certificate_source_type)
        if dns_records is not None:
            pulumi.set(__self__, "dns_records", dns_records)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if validation_status is not None:
            pulumi.set(__self__, "validation_status", validation_status)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Brand id of the domain
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="certificateSourceType")
    def certificate_source_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: `MANUAL`, `OKTA_MANAGED`. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
        """
        return pulumi.get(self, "certificate_source_type")

    @certificate_source_type.setter
    def certificate_source_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_source_type", value)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainDnsRecordArgs']]]]:
        """
        TXT and CNAME records to be registered for the Domain
        """
        return pulumi.get(self, "dns_records")

    @dns_records.setter
    def dns_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainDnsRecordArgs']]]]):
        pulumi.set(self, "dns_records", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom Domain name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="validationStatus")
    def validation_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the domain
        """
        return pulumi.get(self, "validation_status")

    @validation_status.setter
    def validation_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "validation_status", value)


@pulumi.type_token("okta:index/domain:Domain")
class Domain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages custom domain for your organization.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Domain("example", name="www.example.com")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/domain:Domain example <domain_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] brand_id: Brand id of the domain
        :param pulumi.Input[_builtins.str] certificate_source_type: Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: `MANUAL`, `OKTA_MANAGED`. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
        :param pulumi.Input[_builtins.str] name: Custom Domain name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DomainArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages custom domain for your organization.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Domain("example", name="www.example.com")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/domain:Domain example <domain_id>
        ```

        :param str resource_name: The name of the resource.
        :param DomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainArgs.__new__(DomainArgs)

            __props__.__dict__["brand_id"] = brand_id
            __props__.__dict__["certificate_source_type"] = certificate_source_type
            __props__.__dict__["name"] = name
            __props__.__dict__["dns_records"] = None
            __props__.__dict__["validation_status"] = None
        super(Domain, __self__).__init__(
            'okta:index/domain:Domain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            brand_id: Optional[pulumi.Input[_builtins.str]] = None,
            certificate_source_type: Optional[pulumi.Input[_builtins.str]] = None,
            dns_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainDnsRecordArgs', 'DomainDnsRecordArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            validation_status: Optional[pulumi.Input[_builtins.str]] = None) -> 'Domain':
        """
        Get an existing Domain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] brand_id: Brand id of the domain
        :param pulumi.Input[_builtins.str] certificate_source_type: Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: `MANUAL`, `OKTA_MANAGED`. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainDnsRecordArgs', 'DomainDnsRecordArgsDict']]]] dns_records: TXT and CNAME records to be registered for the Domain
        :param pulumi.Input[_builtins.str] name: Custom Domain name
        :param pulumi.Input[_builtins.str] validation_status: Status of the domain
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainState.__new__(_DomainState)

        __props__.__dict__["brand_id"] = brand_id
        __props__.__dict__["certificate_source_type"] = certificate_source_type
        __props__.__dict__["dns_records"] = dns_records
        __props__.__dict__["name"] = name
        __props__.__dict__["validation_status"] = validation_status
        return Domain(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Output[_builtins.str]:
        """
        Brand id of the domain
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="certificateSourceType")
    def certificate_source_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: `MANUAL`, `OKTA_MANAGED`. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
        """
        return pulumi.get(self, "certificate_source_type")

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> pulumi.Output[Sequence['outputs.DomainDnsRecord']]:
        """
        TXT and CNAME records to be registered for the Domain
        """
        return pulumi.get(self, "dns_records")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Custom Domain name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="validationStatus")
    def validation_status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the domain
        """
        return pulumi.get(self, "validation_status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupMembershipsArgs', 'GroupMemberships']

@pulumi.input_type
class GroupMembershipsArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[_builtins.str],
                 users: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 track_all_users: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GroupMemberships resource.
        :param pulumi.Input[_builtins.str] group_id: ID of a Okta group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: The list of Okta user IDs which the group should have membership managed for.
        :param pulumi.Input[_builtins.bool] track_all_users: The resource concerns itself with all users added/deleted to the group; even those managed outside of the resource.
        """
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "users", users)
        if track_all_users is not None:
            pulumi.set(__self__, "track_all_users", track_all_users)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of a Okta group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter
    def users(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The list of Okta user IDs which the group should have membership managed for.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "users", value)

    @_builtins.property
    @pulumi.getter(name="trackAllUsers")
    def track_all_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        The resource concerns itself with all users added/deleted to the group; even those managed outside of the resource.
        """
        return pulumi.get(self, "track_all_users")

    @track_all_users.setter
    def track_all_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "track_all_users", value)


@pulumi.input_type
class _GroupMembershipsState:
    def __init__(__self__, *,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 track_all_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering GroupMemberships resources.
        :param pulumi.Input[_builtins.str] group_id: ID of a Okta group.
        :param pulumi.Input[_builtins.bool] track_all_users: The resource concerns itself with all users added/deleted to the group; even those managed outside of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: The list of Okta user IDs which the group should have membership managed for.
        """
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if track_all_users is not None:
            pulumi.set(__self__, "track_all_users", track_all_users)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of a Okta group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter(name="trackAllUsers")
    def track_all_users(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        The resource concerns itself with all users added/deleted to the group; even those managed outside of the resource.
        """
        return pulumi.get(self, "track_all_users")

    @track_all_users.setter
    def track_all_users(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "track_all_users", value)

    @_builtins.property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of Okta user IDs which the group should have membership managed for.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users", value)


@pulumi.type_token("okta:index/groupMemberships:GroupMemberships")
class GroupMemberships(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 track_all_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource to manage a set of memberships for a specific group.
        This resource will allow you to bulk manage group membership in Okta for a given
        group. This offers an interface to pass multiple users into a single resource
        call, for better API resource usage. If you need a relationship of a single
        user to many groups, please use the 'okta_user_group_memberships' resource.
        **Important**: The default behavior of the resource is to only maintain the
        state of user ids that are assigned it. This behavior will signal drift only if
        those users stop being part of the group. If the desired behavior is track all
        users that are added/removed from the group make use of the 'track_all_users'
        argument with this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.group.Group("test",
            name="testAcc_replace_with_uuid",
            description="testing, testing")
        test_group_memberships = okta.GroupMemberships("test",
            group_id=test.id,
            users=[
                test1["id"],
                test2["id"],
            ])
        ```

        ## Import

        an Okta Group's memberships can be imported via the Okta group ID.

        ```sh
        $ pulumi import okta:index/groupMemberships:GroupMemberships test <group_id>
        ```

        optional parameter track all users will also import all user id currently assigned to the group

        ```sh
        $ pulumi import okta:index/groupMemberships:GroupMemberships test <group_id>/<true>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] group_id: ID of a Okta group.
        :param pulumi.Input[_builtins.bool] track_all_users: The resource concerns itself with all users added/deleted to the group; even those managed outside of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: The list of Okta user IDs which the group should have membership managed for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupMembershipsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource to manage a set of memberships for a specific group.
        This resource will allow you to bulk manage group membership in Okta for a given
        group. This offers an interface to pass multiple users into a single resource
        call, for better API resource usage. If you need a relationship of a single
        user to many groups, please use the 'okta_user_group_memberships' resource.
        **Important**: The default behavior of the resource is to only maintain the
        state of user ids that are assigned it. This behavior will signal drift only if
        those users stop being part of the group. If the desired behavior is track all
        users that are added/removed from the group make use of the 'track_all_users'
        argument with this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.group.Group("test",
            name="testAcc_replace_with_uuid",
            description="testing, testing")
        test_group_memberships = okta.GroupMemberships("test",
            group_id=test.id,
            users=[
                test1["id"],
                test2["id"],
            ])
        ```

        ## Import

        an Okta Group's memberships can be imported via the Okta group ID.

        ```sh
        $ pulumi import okta:index/groupMemberships:GroupMemberships test <group_id>
        ```

        optional parameter track all users will also import all user id currently assigned to the group

        ```sh
        $ pulumi import okta:index/groupMemberships:GroupMemberships test <group_id>/<true>
        ```

        :param str resource_name: The name of the resource.
        :param GroupMembershipsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupMembershipsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 track_all_users: Optional[pulumi.Input[_builtins.bool]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupMembershipsArgs.__new__(GroupMembershipsArgs)

            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["track_all_users"] = track_all_users
            if users is None and not opts.urn:
                raise TypeError("Missing required property 'users'")
            __props__.__dict__["users"] = users
        super(GroupMemberships, __self__).__init__(
            'okta:index/groupMemberships:GroupMemberships',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_id: Optional[pulumi.Input[_builtins.str]] = None,
            track_all_users: Optional[pulumi.Input[_builtins.bool]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'GroupMemberships':
        """
        Get an existing GroupMemberships resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] group_id: ID of a Okta group.
        :param pulumi.Input[_builtins.bool] track_all_users: The resource concerns itself with all users added/deleted to the group; even those managed outside of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users: The list of Okta user IDs which the group should have membership managed for.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupMembershipsState.__new__(_GroupMembershipsState)

        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["track_all_users"] = track_all_users
        __props__.__dict__["users"] = users
        return GroupMemberships(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of a Okta group.
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter(name="trackAllUsers")
    def track_all_users(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        The resource concerns itself with all users added/deleted to the group; even those managed outside of the resource.
        """
        return pulumi.get(self, "track_all_users")

    @_builtins.property
    @pulumi.getter
    def users(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The list of Okta user IDs which the group should have membership managed for.
        """
        return pulumi.get(self, "users")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetServerScopesScopeResult',
]

@pulumi.output_type
class GetServerScopesScopeResult(dict):
    def __init__(__self__, *,
                 consent: _builtins.str,
                 default: _builtins.bool,
                 description: _builtins.str,
                 display_name: _builtins.str,
                 id: _builtins.str,
                 metadata_publish: _builtins.str,
                 name: _builtins.str,
                 optional: _builtins.bool,
                 system: _builtins.bool):
        """
        :param _builtins.str consent: Indicates whether a consent dialog is needed for the Scope
        :param _builtins.bool default: Whether the Scope is a default Scope
        :param _builtins.str description: Description of the Scope
        :param _builtins.str display_name: Name of the end user displayed in a consent dialog box
        :param _builtins.str id: ID of the Scope
        :param _builtins.str metadata_publish: Whether the Scope should be included in the metadata
        :param _builtins.str name: Name of the Scope
        :param _builtins.bool optional: Whether the Scope is optional
        :param _builtins.bool system: Whether Okta created the Scope
        """
        pulumi.set(__self__, "consent", consent)
        pulumi.set(__self__, "default", default)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "metadata_publish", metadata_publish)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "optional", optional)
        pulumi.set(__self__, "system", system)

    @_builtins.property
    @pulumi.getter
    def consent(self) -> _builtins.str:
        """
        Indicates whether a consent dialog is needed for the Scope
        """
        return pulumi.get(self, "consent")

    @_builtins.property
    @pulumi.getter
    def default(self) -> _builtins.bool:
        """
        Whether the Scope is a default Scope
        """
        return pulumi.get(self, "default")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the Scope
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        Name of the end user displayed in a consent dialog box
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the Scope
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="metadataPublish")
    def metadata_publish(self) -> _builtins.str:
        """
        Whether the Scope should be included in the metadata
        """
        return pulumi.get(self, "metadata_publish")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Scope
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def optional(self) -> _builtins.bool:
        """
        Whether the Scope is optional
        """
        return pulumi.get(self, "optional")

    @_builtins.property
    @pulumi.getter
    def system(self) -> _builtins.bool:
        """
        Whether Okta created the Scope
        """
        return pulumi.get(self, "system")


